# Geneweaver Client

This is a client for the [Geneweaver](https://geneweaver.org) API. It is written in 
Python 3.9 and is intended to be used as a library for other applications. It can also 
be used as a command line tool.

## Installation

### From PyPI

```bash
pip install geneweaver-client
```

### From Source
Installing from source requires python 3.9 and [poetry](https://python-poetry.org/).


```bash
git clone $GIT_URL
cd geneweaver-client
poetry install
```

## Usage

### As a library

Coming soon.

### As a command line tool

```bash
gweave --help
```